Citing *TanaT*
-----------------

If you use *TanaT* in a scientific publication, , please cite:

.. code-block:: bibtex

   @inproceedings{tanat2025,
   title={Towards a Library for the Analysis of Temporal Sequences},
   authors={Thomas Guyet and Arnaud Duvermy},
   booktitle={Proceedings of AALTD, ECML Workshop on Advanced Analytics and Learning on Temporal Data},
   year={2025},
   pages={16}
   }